==> blesta-5.10.2.zip: blesta/plugins/system_overview/language/en_us/admin_main.php <==
<?php
// Success messages
$lang['AdminMain.!success.options_updated'] = 'The System Overview settings were successfully updated!';


// Index
$lang['AdminMain.index.boxtitle_overview'] = 'System Overview';


// Overview
$lang['AdminMain.overview.statistic.clients_active'] = 'Active Clients';
$lang['AdminMain.overview.statistic.services_active'] = 'Active Services';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Services Scheduled for Cancellation';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Users Active Today';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Recurring Invoices';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Pending Orders';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Open Tickets';

$lang['AdminMain.overview.heading_users'] = 'Recent Users';

$lang['AdminMain.overview.tab_all'] = 'Graphs';
$lang['AdminMain.overview.tab_clients'] = 'Clients';
$lang['AdminMain.overview.tab_services'] = 'Services';

$lang['AdminMain.overview.tooltip_activity'] = 'Last Activity';
$lang['AdminMain.overview.tooltip_location'] = 'Location';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Just Now';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 minute ago';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s minutes ago'; // %1$s is the number of minutes since the user's last activity


// Date Ranges
$lang['AdminMain.date_range.days'] = '%1$s Days'; // %1$s is the number of days (more than 1)


// Settings
$lang['AdminMain.settings.heading_statistics'] = 'Statistics';
$lang['AdminMain.settings.text_options'] = 'Check the options that will appear on the System Overview.';
$lang['AdminMain.settings.clients_active'] = 'Active Clients';
$lang['AdminMain.settings.services_active'] = 'Active Services';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Services Scheduled for Cancellation';
$lang['AdminMain.settings.active_users_today'] = 'Users Active Today';
$lang['AdminMain.settings.recurring_invoices'] = 'Recurring Invoices';
$lang['AdminMain.settings.open_tickets'] = 'Open Tickets';
$lang['AdminMain.settings.pending_orders'] = 'Pending Orders';

$lang['AdminMain.settings.heading_clients'] = 'Clients Tab';
$lang['AdminMain.settings.text_graphs_clients'] = 'Check which graphs should appear on the Clients Tab.';
$lang['AdminMain.settings.graph_clients'] = 'Clients Graph';

$lang['AdminMain.settings.heading_services'] = 'Services Tab';
$lang['AdminMain.settings.text_graphs_services'] = 'Check which graphs should appear on the Services Tab.';
$lang['AdminMain.settings.graph_services'] = 'Services Graph';

$lang['AdminMain.settings.heading_settings'] = 'Settings';
$lang['AdminMain.settings.show_one_tab'] = 'Show Only One Tab';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'No longer separates graphs in tabs, but instead shows them all in a single tab.';
$lang['AdminMain.settings.show_legend'] = 'Show Legend';
$lang['AdminMain.settings.date_range'] = 'Graph Date Range';

$lang['AdminMain.settings.submit_cancel'] = 'Return to Overview';
$lang['AdminMain.settings.submit_settings'] = 'Update Settings';


// Graphs
$lang['AdminMain.graph_name.graph_services'] = 'Services';
$lang['AdminMain.graph_name.graph_clients'] = 'Clients';
$lang['AdminMain.graph_line_name.active'] = 'Active';
$lang['AdminMain.graph_line_name.canceled'] = 'Canceled';
$lang['AdminMain.graph_line_name.suspended'] = 'Suspended';
$lang['AdminMain.graph_line_name.new'] = 'New';

==> blesta-5.11.4.zip: blesta/plugins/system_overview/language/en_us/admin_main.php <==
<?php
// Success messages
$lang['AdminMain.!success.options_updated'] = 'The System Overview settings were successfully updated!';


// Index
$lang['AdminMain.index.boxtitle_overview'] = 'System Overview';


// Overview
$lang['AdminMain.overview.statistic.clients_active'] = 'Active Clients';
$lang['AdminMain.overview.statistic.services_active'] = 'Active Services';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Services Scheduled for Cancellation';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Users Active Today';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Recurring Invoices';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Pending Orders';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Open Tickets';

$lang['AdminMain.overview.heading_users'] = 'Recent Users';

$lang['AdminMain.overview.tab_all'] = 'Graphs';
$lang['AdminMain.overview.tab_clients'] = 'Clients';
$lang['AdminMain.overview.tab_services'] = 'Services';

$lang['AdminMain.overview.tooltip_activity'] = 'Last Activity';
$lang['AdminMain.overview.tooltip_location'] = 'Location';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Just Now';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 minute ago';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s minutes ago'; // %1$s is the number of minutes since the user's last activity


// Date Ranges
$lang['AdminMain.date_range.ytd'] = 'Year to Date';
$lang['AdminMain.date_range.month'] = 'Current Month';
$lang['AdminMain.date_range.day'] = '1 Day';
$lang['AdminMain.date_range.days'] = '%1$s Days'; // %1$s is the number of days (more than 1)


// Settings
$lang['AdminMain.settings.heading_statistics'] = 'Statistics';
$lang['AdminMain.settings.text_options'] = 'Check the options that will appear on the System Overview.';
$lang['AdminMain.settings.clients_active'] = 'Active Clients';
$lang['AdminMain.settings.services_active'] = 'Active Services';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Services Scheduled for Cancellation';
$lang['AdminMain.settings.active_users_today'] = 'Users Active Today';
$lang['AdminMain.settings.recurring_invoices'] = 'Recurring Invoices';
$lang['AdminMain.settings.open_tickets'] = 'Open Tickets';
$lang['AdminMain.settings.pending_orders'] = 'Pending Orders';

$lang['AdminMain.settings.heading_clients'] = 'Clients Tab';
$lang['AdminMain.settings.text_graphs_clients'] = 'Check which graphs should appear on the Clients Tab.';
$lang['AdminMain.settings.graph_clients'] = 'Clients Graph';

$lang['AdminMain.settings.heading_services'] = 'Services Tab';
$lang['AdminMain.settings.text_graphs_services'] = 'Check which graphs should appear on the Services Tab.';
$lang['AdminMain.settings.graph_services'] = 'Services Graph';

$lang['AdminMain.settings.heading_settings'] = 'Settings';
$lang['AdminMain.settings.show_one_tab'] = 'Show Only One Tab';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'No longer separates graphs in tabs, but instead shows them all in a single tab.';
$lang['AdminMain.settings.show_legend'] = 'Show Legend';
$lang['AdminMain.settings.date_range'] = 'Graph Date Range';

$lang['AdminMain.settings.submit_cancel'] = 'Return to Overview';
$lang['AdminMain.settings.submit_settings'] = 'Update Settings';


// Graphs
$lang['AdminMain.graph_name.graph_services'] = 'Services';
$lang['AdminMain.graph_name.graph_clients'] = 'Clients';
$lang['AdminMain.graph_line_name.active'] = 'Active';
$lang['AdminMain.graph_line_name.canceled'] = 'Canceled';
$lang['AdminMain.graph_line_name.suspended'] = 'Suspended';
$lang['AdminMain.graph_line_name.new'] = 'New';
